@@ -2,7 +2,7 @@
 This script is executed when running `python -m jupytray`.
 """
 
-from jupytray.tray_app import run_app
+from .tray_app import run_app
 
 
 run_app()
