@@ -1,5 +1,7 @@
 from subprocess import Popen
 
+from .settings import settings
+
 
 class NotebookServer:
 
@@ -7,7 +9,10 @@ class NotebookServer:
 
     def start(self):
         if self.process is None:
-            self.process = Popen(["pythonw", "-m", "notebook"])
+            command = ["pythonw", "-m", "notebook"]
+            if settings.root_dir:
+                command.append(f"--notebook-dir={settings.root_dir}")
+            self.process = Popen(command)
 
     def stop(self):
         if self.process is not None:
